@@ -4,7 +4,7 @@ use Mojolicious::Plugin::AssetPack::Asset::Null;
 use Mojolicious::Plugin::AssetPack::Store;
 use Mojolicious::Plugin::AssetPack::Util qw(diag has_ro load_module DEBUG);
 
-our $VERSION = '1.02';
+our $VERSION = '1.03';
 
 has minify => sub { shift->_app->mode ne 'development' };
 
@@ -30,9 +30,12 @@ sub pipe {
 }
 
 sub process {
-  my ($self, $topic) = (shift, shift);
+  my ($self, $topic, @input) = @_;
 
-  return $self->_process_from_def($topic) unless @_;
+  # hack to enable Reloader to work
+  $self->{input}{$topic} = [@input] if @input;
+
+  return $self->_process_from_def($topic) unless @input;
 
   # Used by diag()
   local $Mojolicious::Plugin::AssetPack::Util::TOPIC = $topic;
@@ -41,7 +44,7 @@ sub process {
   # Mojolicious::Plugin::AssetPack::Sprites object, with images to generate
   # CSS from?
   my $assets = Mojo::Collection->new(
-    map { Scalar::Util::blessed($_) ? $_ : $self->store->asset($_) } @_);
+    map { Scalar::Util::blessed($_) ? $_ : $self->store->asset($_) } @input);
 
   # Prepare asset attributes
   $assets->map($_) for qw(checksum mtime);
@@ -198,7 +201,7 @@ Mojolicious::Plugin::AssetPack - Compress and convert css, less, sass, javascrip
 
 =head1 VERSION
 
-1.02
+1.03
 
 =head1 SYNOPSIS
 
